@@ -1,16 +1,8 @@
 import logging
 import socket
+import thread
 
 from handler import RequestHandler, HandlerFactory
-from handler_pool import request_queue
-try:
-    from tcpyconfig import NUM_THREADS
-except:
-    from default import NUM_THREADS
-try:
-    from tcpyconfig import POLL_INTERVAL
-except:
-    from default import POLL_INTERVAL
 try:
     from tcpyconfig import DEBUG
 except:
@@ -33,9 +25,6 @@ class TCPServer(object):
         self.host = host if host else SERVER_DEFAULT
         self.port = port if port else PORT_DEFAULT
         self.commands = kwargs.get("commands", {})
-        threads = kwargs.get("threads", NUM_THREADS)
-        poll_intv = kwargs.get("poll_intv", POLL_INTERVAL)
-        self.request_queue = request_queue(threads, poll_intv)
         self.socket = None
         self.make_conn()
 
@@ -60,5 +49,5 @@ class TCPServer(object):
                                      client_host,
                                      client_port,
                                      client_sock)
-            self.request_queue.add(handler)
+            thread.start_new_thread(handler.handle, ())
         self.socket.close()
